@@ -26,7 +26,7 @@ DEFAULT_STITCH_MAX_LAG = 360
 DEFAULT_STITCH_MAX_ANGLE = 100
 DEFAULT_THREADS = 20
 DEFAULT_WIDTH = 25
-IMAGERY_API_URL = 'http://localhost:10000/api/developer/imagery/poly'
+IMAGERY_API_URL = 'https://hivemapper.com/api/developer/imagery/poly'
 LATEST_IMAGERY_API_URL = 'https://hivemapper.com/api/developer/latest/poly'
 PROBE_API_URL = 'https://hivemapper.com/api/developer/probe'
 RENEW_ASSET_URL = 'https://hivemapper.com/api/developer/renew/'
